==> ikaaro-0.50.4.tar.gz: ikaaro-0.50.4/ui/tiny_mce/themes/advanced/langs/ja.js <==
tinyMCE.addI18n('ja.advanced',{
style_select:"\u30B9\u30BF\u30A4\u30EB",
font_size:"\u30D5\u30A9\u30F3\u30C8\u30B5\u30A4\u30BA",
fontdefault:"\u30D5\u30A9\u30F3\u30C8",
block:"\u30D5\u30A9\u30FC\u30DE\u30C3\u30C8",
paragraph:"\u6BB5\u843D",
div:"Div",
address:"\u4F4F\u6240",
pre:"\u6574\u5F62\u6E08\u307F",
h1:"\u898B\u51FA\u30571",
h2:"\u898B\u51FA\u30572",
h3:"\u898B\u51FA\u30573",
h4:"\u898B\u51FA\u30574",
h5:"\u898B\u51FA\u30575",
h6:"\u898B\u51FA\u30576",
blockquote:"\u5F15\u7528",
code:"\u30BD\u30FC\u30B9\u30B3\u30FC\u30C9",
samp:"\u30B3\u30FC\u30C9\u30B5\u30F3\u30D7\u30EB",
dt:"\u8A9E\u53E5\u5B9A\u7FA9",
dd:"\u8A9E\u53E5\u8AAC\u660E",
bold_desc:"\u592A\u5B57 (Ctrl+B)",
italic_desc:"\u659C\u4F53 (Ctrl+I)",
underline_desc:"\u4E0B\u7DDA (Ctrl+U)",
striketrough_desc:"\u6253\u6D88\u3057\u7DDA",
justifyleft_desc:"\u5DE6\u63C3\u3048",
justifycenter_desc:"\u4E2D\u592E\u63C3\u3048",
justifyright_desc:"\u53F3\u63C3\u3048",
justifyfull_desc:"\u5747\u7B49\u5272\u4ED8",
bullist_desc:"\u756A\u53F7\u306A\u3057\u30EA\u30B9\u30C8",
numlist_desc:"\u756A\u53F7\u3064\u304D\u30EA\u30B9\u30C8",
outdent_desc:"\u30A4\u30F3\u30C7\u30F3\u30C8\u89E3\u9664",
indent_desc:"\u30A4\u30F3\u30C7\u30F3\u30C8",
undo_desc:"\u5143\u306B\u623B\u3059 (Ctrl+Z)",
redo_desc:"\u3084\u308A\u76F4\u3059 (Ctrl+Y)",
link_desc:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
unlink_desc:"\u30EA\u30F3\u30AF\u89E3\u9664",
image_desc:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
cleanup_desc:"\u30B3\u30FC\u30C9\u6574\u5F62",
code_desc:"HTML\u30BD\u30FC\u30B9\u7DE8\u96C6",
sub_desc:"\u4E0B\u4ED8\u304D",
sup_desc:"\u4E0A\u4ED8\u304D",
hr_desc:"\u6C34\u5E73\u7DDA",
removeformat_desc:"\u30D5\u30A9\u30FC\u30DE\u30C3\u30C8\u89E3\u9664",
custom1_desc:"\u8AAC\u660E\u6587\u3092\u5165\u529B\u3057\u3066\u304F\u3060\u3055\u3044\u3002",
forecolor_desc:"\u6587\u5B57\u8272",
backcolor_desc:"\u80CC\u666F\u8272",
charmap_desc:"\u7279\u6B8A\u6587\u5B57",
visualaid_desc:"\u30AC\u30A4\u30C9\u30E9\u30A4\u30F3\u3068\u975E\u8868\u793A\u9805\u76EE\u306E\u8868\u793A\u5207\u66FF",
anchor_desc:"\u30A2\u30F3\u30AB\u30FC\u306E\u633F\u5165/\u7DE8\u96C6",
cut_desc:"\u5207\u308A\u53D6\u308A",
copy_desc:"\u30B3\u30D4\u30FC",
paste_desc:"\u8CBC\u308A\u4ED8\u3051",
image_props_desc:"\u753B\u50CF\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
newdocument_desc:"\u65B0\u898F\u4F5C\u6210",
help_desc:"\u30D8\u30EB\u30D7",
blockquote_desc:"\u5F15\u7528",
clipboard_msg:"\u30B3\u30D4\u30FC/\u5207\u308A\u53D6\u308A/\u8CBC\u308A\u4ED8\u3051\u306FMozilla\u53CA\u3073Firefox\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002\n\u8A73\u7D30\u306F\u3053\u3061\u3089",
path:"\u30D1\u30B9",
newdocument:"\u7DE8\u96C6\u4E2D\u306E\u30C7\u30FC\u30BF\u3092\u7834\u68C4\u3057\u3066\u3082\u3088\u308D\u3057\u3044\u3067\u3059\u304B\uFF1F",
toolbar_focus:"\u30C4\u30FC\u30EB\u30DC\u30BF\u30F3\u3078\u30B8\u30E3\u30F3\u30D7 - Alt+Q, \u30A8\u30C7\u30A3\u30BF\u306B\u30B8\u30E3\u30F3\u30D7 - Alt-Z, \u30A8\u30EC\u30E1\u30F3\u30C8\u30D1\u30B9\u3078\u30B8\u30E3\u30F3\u30D7 - Alt-X",
more_colors:"\u305D\u306E\u4ED6\u306E\u8272"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/themes/advanced/langs/ja.js <==
tinyMCE.addI18n('ja.advanced',{
style_select:"style\u5C5E\u6027",
font_size:"\u30D5\u30A9\u30F3\u30C8\u30B5\u30A4\u30BA",
fontdefault:"\u30D5\u30A9\u30F3\u30C8",
block:"\u30D5\u30A9\u30FC\u30DE\u30C3\u30C8",
paragraph:"\u6BB5\u843D",
div:"Div",
address:"\u4F4F\u6240",
pre:"\u6574\u5F62\u6E08\u307F",
h1:"\u898B\u51FA\u30571",
h2:"\u898B\u51FA\u30572",
h3:"\u898B\u51FA\u30573",
h4:"\u898B\u51FA\u30574",
h5:"\u898B\u51FA\u30575",
h6:"\u898B\u51FA\u30576",
blockquote:"\u5F15\u7528",
code:"\u30BD\u30FC\u30B9\u30B3\u30FC\u30C9",
samp:"\u30B3\u30FC\u30C9\u30B5\u30F3\u30D7\u30EB",
dt:"\u8A9E\u53E5\u5B9A\u7FA9",
dd:"\u8A9E\u53E5\u8AAC\u660E",
bold_desc:"\u592A\u5B57 (Ctrl+B)",
italic_desc:"\u659C\u4F53 (Ctrl+I)",
underline_desc:"\u4E0B\u7DDA (Ctrl+U)",
striketrough_desc:"\u6253\u6D88\u3057\u7DDA",
justifyleft_desc:"\u5DE6\u63C3\u3048",
justifycenter_desc:"\u4E2D\u592E\u63C3\u3048",
justifyright_desc:"\u53F3\u63C3\u3048",
justifyfull_desc:"\u5747\u7B49\u5272\u4ED8",
bullist_desc:"\u756A\u53F7\u306A\u3057\u30EA\u30B9\u30C8",
numlist_desc:"\u756A\u53F7\u3064\u304D\u30EA\u30B9\u30C8",
outdent_desc:"\u30A4\u30F3\u30C7\u30F3\u30C8\u89E3\u9664",
indent_desc:"\u30A4\u30F3\u30C7\u30F3\u30C8",
undo_desc:"\u5143\u306B\u623B\u3059 (Ctrl+Z)",
redo_desc:"\u3084\u308A\u76F4\u3059 (Ctrl+Y)",
link_desc:"\u30EA\u30F3\u30AF\u306E\u633F\u5165/\u7DE8\u96C6",
unlink_desc:"\u30EA\u30F3\u30AF\u89E3\u9664",
image_desc:"\u753B\u50CF\u306E\u633F\u5165/\u7DE8\u96C6",
cleanup_desc:"\u30B3\u30FC\u30C9\u6574\u5F62",
code_desc:"HTML\u30BD\u30FC\u30B9\u7DE8\u96C6",
sub_desc:"\u4E0B\u4ED8\u304D",
sup_desc:"\u4E0A\u4ED8\u304D",
hr_desc:"\u6C34\u5E73\u7DDA",
removeformat_desc:"\u30D5\u30A9\u30FC\u30DE\u30C3\u30C8\u89E3\u9664",
custom1_desc:"\u8AAC\u660E\u6587\u3092\u5165\u529B\u3057\u3066\u304F\u3060\u3055\u3044\u3002",
forecolor_desc:"\u6587\u5B57\u8272",
backcolor_desc:"\u80CC\u666F\u8272",
charmap_desc:"\u7279\u6B8A\u6587\u5B57",
visualaid_desc:"\u30AC\u30A4\u30C9\u30E9\u30A4\u30F3\u3068\u975E\u8868\u793A\u9805\u76EE\u306E\u8868\u793A\u5207\u66FF",
anchor_desc:"\u30A2\u30F3\u30AB\u30FC\u306E\u633F\u5165/\u7DE8\u96C6",
cut_desc:"\u5207\u308A\u53D6\u308A",
copy_desc:"\u30B3\u30D4\u30FC",
paste_desc:"\u8CBC\u308A\u4ED8\u3051",
image_props_desc:"\u753B\u50CF\u306E\u30D7\u30ED\u30D1\u30C6\u30A3",
newdocument_desc:"\u65B0\u898F\u4F5C\u6210",
help_desc:"\u30D8\u30EB\u30D7",
blockquote_desc:"\u5F15\u7528",
clipboard_msg:"\u3053\u306E\u30B3\u30DE\u30F3\u30C9\u306FFirefox\u3067\u306F\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093\u3002",
path:"\u30D1\u30B9",
newdocument:"\u7DE8\u96C6\u4E2D\u306E\u30C7\u30FC\u30BF\u3092\u7834\u68C4\u3057\u3066\u3082\u3088\u308D\u3057\u3044\u3067\u3059\u304B\uFF1F",
toolbar_focus:"\u30C4\u30FC\u30EB\u30DC\u30BF\u30F3\u3078\u30B8\u30E3\u30F3\u30D7 - Alt+Q, \u30A8\u30C7\u30A3\u30BF\u306B\u30B8\u30E3\u30F3\u30D7 - Alt-Z, \u30A8\u30EC\u30E1\u30F3\u30C8\u30D1\u30B9\u3078\u30B8\u30E3\u30F3\u30D7 - Alt-X",
more_colors:"\u305D\u306E\u4ED6\u306E\u8272"
});
